Learn by Examples
=================

.. toctree::
    notebooks/01Load_xml_measurement_files.ipynb.rst
    notebooks/02Common_DataStore_functions_slice_mean_max_std_resample.ipynb.rst
    notebooks/03Define_sections.ipynb.rst
    notebooks/04Calculate_variance_Stokes.ipynb.rst
    notebooks/05Calibrate_single_ols.ipynb.rst
    notebooks/06Calibrate_double_ols.ipynb.rst
    notebooks/07Calibrate_single_wls.ipynb.rst
    notebooks/08Calibrate_double_wls.ipynb.rst
    notebooks/09Import_timeseries.ipynb.rst
    notebooks/10Align_double_ended_measurements.ipynb.rst
